@@ -10,10 +10,14 @@ DBIx::Class::MooseColumns::Meta::Attribute - Attribute metaclass trait for DBIx:
 
 use DBIx::Class::MooseColumns::Meta::Method::Accessor;
 
-has _dbix_class_moosecolumns_column_info => (
-  isa       => 'Maybe[HashRef]',
+has has_dbix_class_moosecolumns_column_info => (
+  isa       => 'Bool',
+  is        => 'rw',
+);
+
+has is_dbix_class_moosecolumns_inflated_column => (
+  isa       => 'Bool',
   is        => 'rw',
-  predicate => 'has__dbix_class_moosecolumns_column_info',
 );
 
 around accessor_metaclass => sub {
@@ -26,6 +30,8 @@ around new => sub {
   my $column_info = delete $options{add_column};
   $column_info->{accessor} = $options{accessor} if $options{accessor};
 
+  my $is_inflated_column;
+
   if ($column_info) {
     my $target_pkg = $options{definition_context}->{package};
     
@@ -33,14 +39,21 @@ around new => sub {
 
     # removing the accessor method that CAG installed (otherwise Moose complains)
     $target_pkg->meta->remove_method($column_info->{accessor} || $name);
+
+    if (exists $target_pkg->column_info($name)->{_inflate_info}) {
+      $is_inflated_column = 1;
+    }
   }
 
   my $self = $class->$orig($name, %options);
 
   if ($column_info) {
-    $self->_dbix_class_moosecolumns_column_info($column_info);
+    $self->has_dbix_class_moosecolumns_column_info(1);
   }
 
+  #TODO respect the API - check for $target_pkg->inflate_column() calls instead of peeking into the guts of the object
+  $self->is_dbix_class_moosecolumns_inflated_column($is_inflated_column);
+
   return $self;
 };
 
